# Based on work by Michael Sarnowski this shows an amazing relationship between
# the mass of the four elementary particles and the fine structure constant.
#
# Removing the neutrino, accuracy to alpha is obtained to -1.855e-8 where the
# relative standard uncertainty is 3.2e-10.  With the neutrino, accuracy is
# obtained to -2.35e-10 against CODATA 2010 alpha.

from math import *

# 2010 CODATA values.  relative uncertainty 1e-8 (not good enough)
me = 9.10938291e-31
mp = 1.672621777e-27
mn = 1.674927351e-27
mev = 5.609588848490029e+29

# de Vries alpha (infinite iterative series)
# http://lkcl.net/reports/fine_structure_constant/alpha.py
fsc = 0.007297352568653858214986442807070539674568087313

# harvard 2012 value
fsc = 1/137.035999173

# 2010 CODATA alpha.  not as precise.  still gives accuracy to within relative uncertainty.
#fsc = 0.0072973525698

# 2010 CODATA values: their use gives relative uncertainty to 4e-10.
# formula below is entirely *relative* masses (except the neutrino mass)
npr = 1/(1.0013784197)
epr = 5.4461702178e-4 # relative standard uncertainty 4.1e-10
mn = mp / npr
me = mp * epr

# http://arxiv.org/abs/1106.5810 equation 11, m1.
nem = 0.049 / mev

# hmm, just something interesting about this neutrino:electron mass ratio:
_ner = sqrt(pi)*pow(e, sqrt(pi))
ner = me/nem
print "me/nem", me, ner, ner/_ner-1

# further support of neutrino mass being 0.049 MeV
# beta- decay of 90Sr an electron and anti-neutrino are emitted at
# up to a total of 0.56MeV.  also interestingly (c) gamma
# ray photons at 0.049 MeV are emitted in isomeric transition
# of 80mBr (neutrino gone slightly wonky)?
# Nuclear and Radiochemistry: Fundamentals and Applications,
# Jens-Volker Kratz, Karl Heinrich Lieser, Section 13.2
# http://goo.gl/wyZRy1
print "0.56-me-ne", me*mev, nem*mev, me*mev + nem * mev

# 1st equation

# http://vixra.org/abs/1403.0502 equation 2 and equation in section IV
t = pow((mp * mp - 2*mp*me + pow(me, 2) + 2*pow(mn, 2) + \
                (4*nem*me - nem*nem)) / pow(mn, 2), 0.5)
print "t", t
_alpha = me * t / 4 / mn * pow(pi, 3) 

# answer comes out to -7.78e-11 using de vries alpha! wow!
# comes out to 2.35e-10 using 2010 CODATA alpha.
print "alpha", _alpha, _alpha/fsc-1

# 2nd equation

# http://vixra.org/abs/1403.0502 equation 2 and equation in section IV
t = pow((mp * mp - 2*mp*me + pow(me, 2) + 2*pow(mn, 2) )\
                / pow(mn, 2), 0.5)
print "t", t
t += (nem*me + sqrt(2)*nem*nem)/pow(mn,2)
_alpha = me * t / 4 / mn * pow(pi, 3) 

# answer comes out to 5.11e-11 using de vries alpha.
# comes out to -1.06e-10 using 2010 CODATA alpha.
print "alpha", _alpha, _alpha/fsc-1

# show remainder, becomes hard to track down as it's beyond experimental
# uncertainty for mass values.
diff = fsc - _alpha
diff = diff / (me / 4 / mn * pow(pi, 3))
print "diff ratio", diff, pow(diff, 2) * pow(mn, 2)

# 3rd equation.  

# this value was found using binary search to track down a value,
# just to see what would happen
nem = 0.000052341 / mev

# then we do the same funny trick to find a number matching it and
# WOW!  (2 pi)^5 to within 4dp (2.7e-4).  not bad grandpa :)
ner = me/nem
_ner = pow(2 * pi, 5)
print "me/nem", me, ner, ner/_ner-1

# http://vixra.org/abs/1403.0502 equation 2 and equation in section IV
t = pow((mp * mp - 2*mp*me + pow(me, 2) + 2*pow(mn, 2))\
                / pow(mn, 2), 0.5)
t = pow((pow(mp - me + nem, 2) + 2*pow(mn, 2))\
                / pow(mn, 2), 0.5)
print "t", t
#t += (pi*2*nem*me)/pow(mn,2)
_alpha = me * t / 4 / mn * pow(pi, 3) 

# answer comes out to 5.11e-11 using de vries alpha.
# comes out to -1.06e-10 using 2010 CODATA alpha.
print "alpha", _alpha, _alpha/fsc-1

# show remainder, becomes hard to track down as it's beyond experimental
# uncertainty for mass values.
diff = fsc - _alpha
diff = diff / (me / 4 / mn * pow(pi, 3))
print "diff ratio", diff, pow(diff, 2) * pow(mn, 2)


# 4th equation.  

# this value was found using binary search to track down a value,
# just to see what would happen
nem = 0.00005244171 / mev
nem = 0.000050850305 / mev # use harvard 2012 fsc value

# still (2 pi)^5 to within 3dp.
# difference when using 2012 fsc value @ 5th root: cospi(1/x)^2 = cospi(fsc)  
ner = me/nem
_ner = pow(2 * pi, 5)
_ner = pow(pi*2*pi/acos(-sqrt(cos(fsc*pi))), 5) # 2012 fsc value
print "me/nem", me, ner, ner/_ner-2

t = pow((pow(mp - me, 2) + 2*pow(mn - nem, 2))\
                / pow(mn - nem, 2), 0.5)
print "t", t
#t += (pi*2*nem*me)/pow(mn,2)
_alpha = me * t / 4 / mn * pow(pi, 3) 

# answer comes out to 5.11e-11 using de vries alpha.
# comes out to -1.06e-10 using 2010 CODATA alpha.
print "alpha", _alpha, _alpha/fsc-1

# show remainder, becomes hard to track down as it's beyond experimental
# uncertainty for mass values.
diff = fsc - _alpha
diff = diff / (me / 4 / mn * pow(pi, 3))
print "diff ratio", diff, pow(diff, 2) * pow(mn, 2)

# Mikhail Vlasov http://en.wikipedia.org/wiki/User:Korablino
gmr = (1 + pow(5, 0.5))/2
_npr = sqrt(1 - fsc / (log(2 * pi + 7.905910795)))
_npr = sqrt(1 - fsc * ((log(2) / log(2 * pi)) -1.39009905e-4))
x = (e*2*gmr+1) / pow(log(4), 4)
_npr = sqrt(1 - fsc / x)
print "np ratio", npr, _npr, _npr/npr-1
